CounterStyleType

Type Alias CounterStyleType 

type CounterStyleType = T;

Aliased Type

enum CounterStyleType {
Show 34 variants Disc, None, Circle, Square, DisclosureOpen, DisclosureClosed, Decimal, LowerAlpha, UpperAlpha, ArabicIndic, Bengali, Cambodian, CjkDecimal, Devanagari, Gujarati, Gurmukhi, Kannada, Khmer, Lao, Malayalam, Mongolian, Myanmar, Oriya, Persian, Telugu, Thai, Tibetan, CjkEarthlyBranch, CjkHeavenlyStem, LowerGreek, Hiragana, HiraganaIroha, Katakana, KatakanaIroha,
}

Variants



Disc

A filled circle, similar to • U+2022 BULLET. https://www.w3.org/TR/css-counter-styles-3/#disc



None



Circle

A hollow circle, similar to ◦ U+25E6 WHITE BULLET. https://www.w3.org/TR/css-counter-styles-3/#circle



Square

A filled square, similar to ▪ U+25AA BLACK SMALL SQUARE. https://www.w3.org/TR/css-counter-styles-3/#square



DisclosureOpen

Symbol for indicating an open disclosure widget, such as the HTML <details> element. https://www.w3.org/TR/css-counter-styles-3/#disclosure-open



DisclosureClosed

Symbol for indicating a closed disclosure widget, such as the HTML <details> element. https://www.w3.org/TR/css-counter-styles-3/#disclosure-closed



Decimal

Western decimal numbers (e.g., 1, 2, 3, …, 98, 99, 100). https://www.w3.org/TR/css-counter-styles-3/#decimal



LowerAlpha

Lowercase ASCII letters (e.g., a, b, c, …, z, aa, ab). https://www.w3.org/TR/css-counter-styles-3/#lower-alpha



UpperAlpha

Uppercase ASCII letters (e.g., A, B, C, …, Z, AA, AB). https://www.w3.org/TR/css-counter-styles-3/#upper-alpha



ArabicIndic

Arabic-indic numbering (e.g.، ١، ٢، ٣، ٤، …، ٩٨، ٩٩، ١٠٠). https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-arabic-indic



Bengali

Bengali numbering (e.g., ১, ২, ৩, …, ৯৮, ৯৯, ১০০). https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-bengali



Cambodian

Cambodian/Khmer numbering (e.g., ១, ២, ៣, …, ៩៨, ៩៩, ១០០). https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-cambodian



CjkDecimal

Han decimal numbers (e.g., 一, 二, 三, …, 九八, 九九, 一〇〇). https://www.w3.org/TR/css-counter-styles-3/#cjk-decimal



Devanagari

devanagari numbering (e.g., १, २, ३, …, ९८, ९९, १००). https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-devanagari



Gujarati

Gujarati numbering (e.g., ૧, ૨, ૩, …, ૯૮, ૯૯, ૧૦૦). https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-gujarati



Gurmukhi

Gurmukhi numbering (e.g., ੧, ੨, ੩, …, ੯੮, ੯੯, ੧੦੦). https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-gurmukhi



Kannada

Kannada numbering (e.g., ೧, ೨, ೩, …, ೯೮, ೯೯, ೧೦೦). https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-kannada



Khmer

Cambodian/Khmer numbering (e.g., ១, ២, ៣, …, ៩៨, ៩៩, ១០០). https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-khmer



Lao

Laotian numbering (e.g., ໑, ໒, ໓, …, ໙໘, ໙໙, ໑໐໐). <https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-lao<



Malayalam

Malayalam numbering (e.g., ൧, ൨, ൩, …, ൯൮, ൯൯, ൧൦൦). https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-malayalam



Mongolian

Mongolian numbering (e.g., ᠑, ᠒, ᠓, …, ᠙᠘, ᠙᠙, ᠑᠐᠐). https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-mongolian



Myanmar

Myanmar (Burmese) numbering (e.g., ၁, ၂, ၃, …, ၉၈, ၉၉, ၁၀၀). https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-myanmar



Oriya

Oriya numbering (e.g., ୧, ୨, ୩, …, ୯୮, ୯୯, ୧୦୦). https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-oriya



Persian

Persian numbering (e.g., ۱, ۲, ۳, ۴, …, ۹۸, ۹۹, ۱۰۰). https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-persian



Telugu

Telugu numbering (e.g., ౧, ౨, ౩, …, ౯౮, ౯౯, ౧౦౦). https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-telugu



Thai

Thai (Siamese) numbering (e.g., ๑, ๒, ๓, …, ๙๘, ๙๙, ๑๐๐). https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-thai



Tibetan

Tibetan numbering (e.g., ༡, ༢, ༣, …, ༩༨, ༩༩, ༡༠༠). https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-tibetan



CjkEarthlyBranch

Han “Earthly Branch” ordinals (e.g., 子, 丑, 寅, …, 亥). https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-cjk-earthly-branch



CjkHeavenlyStem

Han “Heavenly Stem” ordinals (e.g., 甲, 乙, 丙, …, 癸) https://www.w3.org/TR/css-counter-styles-3/#valdef-counter-style-name-cjk-heavenly-stem



LowerGreek

Lowercase classical Greek (e.g., α, β, γ, …, ω, αα, αβ). https://www.w3.org/TR/css-counter-styles-3/#lower-greek



Hiragana

Dictionary-order hiragana lettering (e.g., あ, い, う, …, ん, ああ, あい). https://www.w3.org/TR/css-counter-styles-3/#hiragana



HiraganaIroha

Iroha-order hiragana lettering (e.g., い, ろ, は, …, す, いい, いろ). https://www.w3.org/TR/css-counter-styles-3/#hiragana-iroha



Katakana

Dictionary-order katakana lettering (e.g., ア, イ, ウ, …, ン, アア, アイ). https://www.w3.org/TR/css-counter-styles-3/#katakana



KatakanaIroha

Iroha-order katakana lettering (e.g., イ, ロ, ハ, …, ス, イイ, イロ) https://www.w3.org/TR/css-counter-styles-3/#katakana-iroha